@@ -1,7 +1,11 @@
+from dataclasses import dataclass
+from enum import Enum
 from pydantic import BaseModel
 from typing import List, Optional
 from datetime import datetime
-from .crypto_models import FileKey
+
+from dracoon.user_models import UserInfo
+from .crypto_models import EncryptionInfo, FileKey
 
 # required payload for POST /nodes/{node_id}/comments
 class CommentNode(BaseModel):
@@ -51,6 +55,23 @@ class CreateUploadChannel(BaseModel):
     timestampCreation: Optional[datetime]
     timestampModificiation: Optional[datetime]
 
+
+class S3Part(BaseModel):
+    partNumber: int
+    partEtag: str
+
+class CompleteS3Upload(BaseModel):
+    parts: List[S3Part]
+    resolutionStrategy: Optional[str]
+    keepShareLinks: Optional[bool]
+    fileName: Optional[str]
+    fileKey: Optional[FileKey]
+
+class GetS3Urls(BaseModel):
+    firstPartNumber: int
+    lastPartNumber: int
+    size: int
+
 # required payload for POST /nodes/folders
 class CreateFolder(BaseModel):
     parentId: int
@@ -104,9 +125,17 @@ class ConfigRoom(BaseModel):
 # required payload for PUT /nodes/files
 class UpdateFiles(BaseModel):
     classification: Optional[int]
-    expiration: Expiration
+    expiration: Optional[Expiration]
     objectIds: List[int]
 
+class UpdateFile(BaseModel):
+    name: Optional[str]
+    expiration: Optional[Expiration]
+    classification: Optional[int]
+    notes: Optional[str]
+    timestampCreation: Optional[datetime]
+    timestampModification: Optional[datetime]
+
 
 class Permissions(BaseModel):
     manage: bool
@@ -126,6 +155,8 @@ class UpdateRoomUserItem(BaseModel):
     permissions: Permissions
 
 class UpdateRoomGroupItem(UpdateRoomUserItem):
+    id: int
+    permissions: Permissions
     newGroupMemberAcceptance: Optional[str]
 
 # required payload for PUT /nodes/rooms/{room_id}/groups
@@ -149,7 +180,7 @@ class ProcessRoomPendingItem(BaseModel):
     userId: int
     groupId: int
     roomId: int
-    roomName: int
+    roomName: str
     state: str
 
 # required payload for PUT /nodes/rooms/{room_id}/pending
@@ -157,6 +188,53 @@ class ProcessRoomPendingUsers(BaseModel):
     items: List[ProcessRoomPendingItem]
 
 
+class NodeType(Enum):
+    file = "file"
+    folder = "folder"
+    room = "room"
+
+class Node(BaseModel):
+    id: int
+    type: NodeType
+    name: str
+    timestampCreation: Optional[datetime]
+    timestampModification: Optional[datetime]
+    parentId: Optional[int]
+    parentPath: Optional[str]
+    createdAt: Optional[datetime]
+    updatedAt: Optional[datetime]
+    createdBy: Optional[UserInfo]
+    updatedBy: Optional[UserInfo]
+    expireAt: Optional[datetime]
+    hash: Optional[str]
+    fileType: Optional[str]
+    mediaType: Optional[str]
+    size: Optional[int]
+    classification: Optional[int]
+    notes: Optional[str]
+    permissions: Optional[Permissions]
+    inheritPermissions: Optional[bool]
+    isEncrypted: Optional[bool]
+    encryptionInfo: Optional[EncryptionInfo]
+    cntDeletedVersions: Optional[int]
+    cntComments: Optional[int]
+    cntDownloadShares: Optional[int]
+    cntUploadShares: Optional[int]
+    recycleBinRetentionPeriod: Optional[int]
+    hasActivitiesLog: Optional[bool]
+    quota: Optional[int]
+    isFavorite: Optional[bool]
+    branchVersion: Optional[int]
+    mediaToken: Optional[str]
+    isBrowsable: Optional[bool]
+    cntRooms: Optional[int]
+    contFolders: Optional[int]
+    cntFiles: Optional[int]
+    authParentId: Optional[int]
+
+
+
+
 
 
 
